#
# spec file
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Archie L. Cobbs <archie@dellroad.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mod_name           mod_authn_otp
Name:           apache2-%{mod_name}
Version:        1.1.11
Release:        1.3
Summary:        Apache module for one-time password authentication
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
URL:            https://github.com/archiecobbs/mod-authn-otp
Source:         https://s3.amazonaws.com/archie-public/mod-authn-otp/%{mod_name}-%{version}.tar.gz
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  pkgconfig(openssl)
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Provides:       genotpurl = %{version}
Provides:       otplock = %{version}
Provides:       otptool = %{version}

%description
mod_authn_otp is an Apache web server module for two-factor authentication
using one-time passwords (OTP) generated via the HOTP/OATH algorithm
defined in RFC 4226. This creates a simple way to protect a web site with
one-time passwords, using any RFC 4226-compliant hardware or software
token device. mod_authn_otp also supports the Mobile-OTP algorithm.

mod_authn_otp supports both event and time based one-time passwords. It
also supports "lingering" which allows the repeated re-use of a previously
used one-time password up to a configurable maximum linger time. This
allows one-time passwords to be used directly in HTTP authentication
without forcing the user to enter a new one-time password for every
page load.

mod_authn_otp supports both basic and digest authentication, and will
auto-synchronize with the user's token within a configurable maximum
offset (auto-synchronization is not supported with digest authentication).

mod_authn_otp is especially useful for setting up protected web sites
that require more security than simple username/password authentication
yet also don't require users to install special VPN software, and is
compatible with software tokens that run on cell phones.

Also included are three command line utilities, otptool, otplock, and
genotpurl. otptool is a one-time password command line utility. It can
be used on a simple call-out basis to integrate two-factor authentication
into any existing authentication solution. otplock allows you to safely
modify the users file while Apache is running. genotpurl generates URLs
for the Google Authenticator app.

%prep
%setup -q -n %{mod_name}-%{version}

%build
%configure
%make_build

%install
install -d %{buildroot}%{apache_libexecdir}
%make_install

%files
%license LICENSE
%doc CHANGES README users.sample
%{apache_libexecdir}/%{mod_name}.so
%{_bindir}/otptool
%{_bindir}/otplock
%{_bindir}/genotpurl
%{_mandir}/man1/otptool.1.gz
%{_mandir}/man1/otplock.1.gz
%{_mandir}/man1/genotpurl.1.gz

%changelog
* Thu Jun 27 2024 Archie Cobbs <archie.cobbs@gmail.com>
- Update to version 1.1.11
  - Fixed build issue with libapr on some systems (issue #48)
  - Added otplock(1) utility (issue #38)
* Thu Jun 20 2024 pgajdos@suse.com
- drop unmaintained apache-rex usage
* Wed May  4 2022 Archie Cobbs <archie.cobbs@gmail.com>
- Update to version 1.1.10
  + Fixed bug in genotpurl on platforms with signed "char" (pr #46)
  + Added "-K" flag to genotpurl tool to specify key length (pr #43)
  + Update spec file description to include genotpurl(1)
* Fri Apr 23 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed SPEC file: Replaced broken URL and minor cleanup
* Wed Jun 26 2019 pgajdos@suse.com
- testing with apache-rex instead
* Sat Jun 22 2019 archie.cobbs@gmail.com
- Update to version 1.1.9
  + Added genotpurl(1) utility
  + Added "-F" flag to otptool(1).
* Mon Oct 30 2017 archie.cobbs@gmail.com
- Update to version 1.1.8
  + Added PINFakeBasicAuth configuration option
* Fri Dec 11 2015 pgajdos@suse.com
- %%{apache_branch} converted to number
* Sun Oct  4 2015 pgajdos@suse.com
- %%check for apache 2.2 again
* Thu Oct  1 2015 pgajdos@suse.com
- do not %%check for apache 2.2
* Fri Sep 25 2015 pgajdos@suse.com
- test module with %%apache_test_module_curl
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Fri Oct 31 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Wed May 28 2014 tchvatal@suse.com
- Fix source download url.
* Sat May 17 2014 archie@dellroad.org
- Update to version 1.1.7
  + Fixed bug where users file could get deleted when using Apache worker MPM (issue #22)
  + Added "OTPAuthFallThrough" to allow fall through to other auth providers (issue #23)
  + Allow "logout" by sending empty password (issue #24)
  + Count PINs against OTPAuthMaxOTPFailure even when they have the wrong length
* Wed Apr  3 2013 archie@dellroad.org
- Update to version 1.1.6
  + Detect errors when writing to the new users.txt file
  + Fix (harmless) bug where new users.txt file was not being closed
- Use correct license string in spec file
- Add copyright notice to spec file
* Fri Nov 30 2012 archie@dellroad.org
- Update to version 1.1.5
  + Allow building on systems without strptime(3) (e.g., Windows)
  + Add support for Apache 2.4.x
* Tue Nov 27 2012 archie@dellroad.org
- Upgrade to version 1.1.4
  + Always allow stale time-based offsets to re-synchronize (issue #14)
  + Added "OTPAuthMaxOTPFailure" to lock accounts after repeated wrong OTP's
  + Fixed bug with "OTPAuthPINAuthProvider" and <AuthnProviderAlias>
  + Added "OTPAuthPINAuthProvider" to allow alternate verification of PINs
  + Added "OTPAuthLogoutOnIPChange" flag to auto-logout on IP address change
* Thu Mar  3 2011 draht@suse.de
- upgrade to build fix release 1.1.1
